<?php

use Illuminate\Support\Str;
use Illuminate\Support\Collection;
use Illuminate\Support\HtmlString;
use Illuminate\Support\Facades\Request;


if ( !function_exists('col_sort')) {
    /**
     * Affiche un icon de tri de colonne dans une vue liste
     * @param  String $filter_name Nom de la colonne à trier (nom en BDD)
     * @return String              Le HTML permettant le tri (icon + lien)
     */
    function col_sort($filter_name)
    {
        // Récupération des paramètres de tri
        $url_filter_name = Request::get('sorting');
        $url_filter_sort = Request::get('direction');

        // Si le paramètre de tri correspond à celui de l'url
        if ($url_filter_name == $filter_name) {

            // En fonction du sens de tri
            if ($url_filter_sort == 'desc') {

                $url_params = ['sorting' => $filter_name, 'direction' => 'asc'];
                $icon = '<span class="sort desc ml-1"><i class="fa fa-sort-amount-desc"></i></span>';

            } else {

                $url_params = ['sorting' => $filter_name, 'direction' => 'desc'];
                $icon = '<span class="sort asc ml-1"><i class="fa fa-sort-amount-asc"></i></span>';

            }

        } else {

            $url_params = ['sorting' => $filter_name, 'direction' => 'asc'];
            $icon = '<span class="sort ml-1"><i class="fa fa-sort"></i></span>';
        }

        // Création du html pour l'icone de tri
        $html = '<a href="' . Request::fullUrlWithQuery($url_params) . '">' . $icon . '<a>';


        return new HtmlString($html);
    }
}

if ( !function_exists('pos_sort')) {
    /**
     * Affichage d'un visuel pour tri des colonnes « position » en drag & drop
     * @param  string $id_position    ID + POSITION de l'item
     * @return String                 Le visuel permettant le tri de position
     */
    function pos_sort($item_id, $item_position)
    {
        // Récupération des paramètres de tri
        $url_filter_name = Request::get('sorting');
        $url_filter_sort = Request::get('direction');

        // Si les conditions de tri sont réunis
        if ($url_filter_name == 'position' && $url_filter_sort == 'asc') {
            $html  = '<div class="position-wrap">';
            $html .= '<i class="fa fa-arrows" aria-hidden="true"></i>';
            $html .= '<span class="position" data-sort="' . $item_position . '" data-id="' . $item_id . '">' . $item_position . '</span>';
            $html .= '</div>';

            return new HtmlString($html);
        }

        return $item_position;
    }
}
