<?php

use Illuminate\Support\HtmlString;
use Illuminate\Support\Collection;
use Illuminate\Support\Str;


if ( !function_exists('sum_times')) {
    /**
     * Additionne tableau de string au format `hh:mm:ss` pour en afficher un total formaté
     * @param  Array $times      Tableau d'heures à additionner
     * @param  Integer $segments Le nombre de segments souhaités (defaut : 3)
     * @return String            Le resultat de la somme formaté
     */
    function sum_times($times, $segments = 3)
    {
        $hou        = 0;
        $min        = 0;
        $sec        = 0;
        $total_time = '00:00';

        foreach ($times as $time) {
            $split = explode(":", $time);

            $hou   += intval(@$split[0]);
            $min   += intval(@$split[1]);
            $sec   += intval(@$split[2]);
        }

        $seconds = $sec % 60;
        $minutes = $sec / 60;
        $minutes = (integer)$minutes;
        $minutes += $min;
        $hours   = $minutes / 60;
        $minutes = $minutes % 60;
        $hours   = (integer)$hours;
        $hours   += $hou;

        // Formatage 0:00:00
        $minutes = sprintf('%02d', $minutes);
        $seconds = sprintf('%02d', $seconds);

        switch ($segments) {
            case 1 :
                $result = $hours;
                break;
            case 2 :
                $result = $hours.":".$minutes;
                break;

            default :
                $result = $hours.":".$minutes.":".$seconds;
                break;
        }

        return $result;
    }
}

if ( !function_exists('gte_time')) {
    /**
     * Compare un string de type horaire avec un autre (plus grand ou égal à)
     * @param  String $time1    Heure 1
     * @param  String $time2    Heure 2
     * @return Boolean          Heure 1 supérieur à heure 2
     */
    function gte_time($time1, $time2)
    {
        $hou  = 0;
        $min  = 0;
        $sec  = 0;
        $sec1 = 0;
        $sec2 = 0;

        // Dispatch des valeurs heure 1
        $split = explode(":", $time1);

        if (empty(@$split[0])) {
            return -1;
        }

        $hou = intval(@$split[0]);
        $min = intval(@$split[1]);
        $sec = intval(@$split[2]);

        // Calcul du nombre de secondes heure 1
        $sec1  = $sec;
        $sec1 += $min * 60;
        $sec1 += $hou * 60 * 60;

        // Dispatch des valeurs 2
        $split = explode(":", $time2);

        if (empty(@$split[0])) {
            return -1;
        }

        $hou = intval(@$split[0]);
        $min = intval(@$split[1]);
        $sec = intval(@$split[2]);

        // Calcul du nombre de secondes heure 2
        $sec2  = $sec;
        $sec2 += $min * 60;
        $sec2 += $hou * 60 * 60;

        // Comparaison
        return $sec1 >= $sec2;
    }
}

if (!function_exists('time_to_float')) {

    /**
     * Convertir une heure de type HH:MM:SS en nombre flottant
     *
     * @param string $time
     * @return float
     */
    function time_to_float($time): float
    {
        $float = 0;
        $split = explode(":", $time);

        $hou = intval(@$split[0]);
        $min = intval(@$split[1]);
        $sec = intval(@$split[2]);

        // On met tout en seconde
        $seconds  = $hou * 60 * 60;
        $seconds += $min * 60;
        $seconds += $sec;

        $float = $seconds / 3600;

        return $float;
    }
}
